==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/OSProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specifies the operating system settings for the hybrid machine.
 * @property linuxConfiguration Specifies the linux configuration for update management.
 * @property windowsConfiguration Specifies the windows configuration for update management.
 */
public data class OSProfileArgs(
    public val linuxConfiguration: Output<OSProfileLinuxConfigurationArgs>? = null,
    public val windowsConfiguration: Output<OSProfileWindowsConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs =
        com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs.builder()
            .linuxConfiguration(
                linuxConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .windowsConfiguration(
                windowsConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OSProfileArgs].
 */
@PulumiTagMarker
public class OSProfileArgsBuilder internal constructor() {
    private var linuxConfiguration: Output<OSProfileLinuxConfigurationArgs>? = null

    private var windowsConfiguration: Output<OSProfileWindowsConfigurationArgs>? = null

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("kreaqtvtbjsofetv")
    public suspend fun linuxConfiguration(`value`: Output<OSProfileLinuxConfigurationArgs>) {
        this.linuxConfiguration = value
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("sstxwsjrvmhrdkfi")
    public suspend fun windowsConfiguration(`value`: Output<OSProfileWindowsConfigurationArgs>) {
        this.windowsConfiguration = value
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("bmsrdpbeheelsuun")
    public suspend fun linuxConfiguration(`value`: OSProfileLinuxConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linuxConfiguration = mapped
    }

    /**
     * @param argument Specifies the linux configuration for update management.
     */
    @JvmName("gwasvfnhuvemyrfu")
    public suspend
    fun linuxConfiguration(argument: suspend OSProfileLinuxConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OSProfileLinuxConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.linuxConfiguration = mapped
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("kcmervcjosephdrm")
    public suspend fun windowsConfiguration(`value`: OSProfileWindowsConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsConfiguration = mapped
    }

    /**
     * @param argument Specifies the windows configuration for update management.
     */
    @JvmName("ypyursqtfifetdcg")
    public suspend
    fun windowsConfiguration(argument: suspend OSProfileWindowsConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OSProfileWindowsConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.windowsConfiguration = mapped
    }

    internal fun build(): OSProfileArgs = OSProfileArgs(
        linuxConfiguration = linuxConfiguration,
        windowsConfiguration = windowsConfiguration,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridcompute/kotlin/inputs/OSProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcompute.kotlin.inputs

import com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Specifies the operating system settings for the hybrid machine.
 * @property linuxConfiguration Specifies the linux configuration for update management.
 * @property windowsConfiguration Specifies the windows configuration for update management.
 */
public data class OSProfileArgs(
    public val linuxConfiguration: Output<OSProfileLinuxConfigurationArgs>? = null,
    public val windowsConfiguration: Output<OSProfileWindowsConfigurationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs =
        com.pulumi.azurenative.hybridcompute.inputs.OSProfileArgs.builder()
            .linuxConfiguration(
                linuxConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .windowsConfiguration(
                windowsConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [OSProfileArgs].
 */
@PulumiTagMarker
public class OSProfileArgsBuilder internal constructor() {
    private var linuxConfiguration: Output<OSProfileLinuxConfigurationArgs>? = null

    private var windowsConfiguration: Output<OSProfileWindowsConfigurationArgs>? = null

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("aviqrketcbddwtyt")
    public suspend fun linuxConfiguration(`value`: Output<OSProfileLinuxConfigurationArgs>) {
        this.linuxConfiguration = value
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("opxpehvvbvwayndv")
    public suspend fun windowsConfiguration(`value`: Output<OSProfileWindowsConfigurationArgs>) {
        this.windowsConfiguration = value
    }

    /**
     * @param value Specifies the linux configuration for update management.
     */
    @JvmName("escbgekawytiimok")
    public suspend fun linuxConfiguration(`value`: OSProfileLinuxConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linuxConfiguration = mapped
    }

    /**
     * @param argument Specifies the linux configuration for update management.
     */
    @JvmName("idwltqivgqmhvwio")
    public suspend
    fun linuxConfiguration(argument: suspend OSProfileLinuxConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OSProfileLinuxConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.linuxConfiguration = mapped
    }

    /**
     * @param value Specifies the windows configuration for update management.
     */
    @JvmName("bjjgtcyrrovpqhth")
    public suspend fun windowsConfiguration(`value`: OSProfileWindowsConfigurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.windowsConfiguration = mapped
    }

    /**
     * @param argument Specifies the windows configuration for update management.
     */
    @JvmName("plvxptbrcxcctruf")
    public suspend
    fun windowsConfiguration(argument: suspend OSProfileWindowsConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = OSProfileWindowsConfigurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.windowsConfiguration = mapped
    }

    internal fun build(): OSProfileArgs = OSProfileArgs(
        linuxConfiguration = linuxConfiguration,
        windowsConfiguration = windowsConfiguration,
    )
}
